ElfHeader

Struct ElfHeader 

#[repr(C)]
pub struct ElfHeader {
Show 14 fields pub e_ident: [u8; 16], pub e_type: u16, pub e_machine: u16, pub e_version: u32, pub e_entry: u64, pub e_phoff: u64, pub e_shoff: u64, pub e_flags: u32, pub e_ehsize: u16, pub e_phentsize: u16, pub e_phnum: u16, pub e_shentsize: u16, pub e_shnum: u16, pub e_shstrndx: u16,
}

Fields

e_ident: [u8; 16]e_type: u16e_machine: u16e_version: u32e_entry: u64e_phoff: u64e_shoff: u64e_flags: u32e_ehsize: u16e_phentsize: u16e_phnum: u16e_shentsize: u16e_shnum: u16e_shstrndx: u16

Implementations

Source

impl ElfHeader

pub const ELF_MAGIC: [u8; 4]

pub const ET_EXEC: u16 = 2

pub const ET_DYN: u16 = 3

pub const EM_X86_64: u16 = 0x3E

pub fn new(elf: &[u8]) -> &Self

Takes an ELF byte slice and returns it as a reference to an ElfHeader

Safety

The caller should make sure that the given byte slice is ELF data to avoid undefined behavior